@@ -11,18 +11,10 @@ class copyIsoCmd (baseCmd):
         """ID of the zone the template is being copied to."""
         """Required"""
         self.destzoneid = None
-        """ID of the zone the template is being copied to."""
-        """Required"""
-        self.destzoneid = None
         """ID of the zone the template is currently hosted on."""
         """Required"""
         self.sourcezoneid = None
-        """ID of the zone the template is currently hosted on."""
-        """Required"""
-        self.sourcezoneid = None
-        """"""
-        self.starteventid = None
-        self.required = ["id","destzoneid","destzoneid","sourcezoneid","sourcezoneid",]
+        self.required = ["id","destzoneid","sourcezoneid",]
 
 class copyIsoResponse (baseResponse):
     def __init__(self):
