@@ -14,8 +14,6 @@ class copyTemplateCmd (baseCmd):
         """ID of the zone the template is currently hosted on."""
         """Required"""
         self.sourcezoneid = None
-        """"""
-        self.starteventid = None
         self.required = ["id","destzoneid","sourcezoneid",]
 
 class copyTemplateResponse (baseResponse):
