@@ -16,8 +16,6 @@ class createTagsCmd (baseCmd):
         self.tags = []
         """identifies client specific tag. When the value is not null, the tag can't be used by cloudStack code internally"""
         self.customer = None
-        """"""
-        self.starteventid = None
         self.required = ["resourceids","resourcetype","tags",]
 
 class createTagsResponse (baseResponse):
