@@ -8,12 +8,6 @@ class createVirtualRouterElementCmd (baseCmd):
         """the network service provider ID of the virtual router element"""
         """Required"""
         self.nspid = None
-        """"""
-        self.id = None
-        """"""
-        self.id = None
-        """"""
-        self.starteventid = None
         self.required = ["nspid",]
 
 class createVirtualRouterElementResponse (baseResponse):
