@@ -8,8 +8,6 @@ class deleteNetworkServiceProviderCmd (baseCmd):
         """the ID of the network service provider"""
         """Required"""
         self.id = None
-        """"""
-        self.starteventid = None
         self.required = ["id",]
 
 class deleteNetworkServiceProviderResponse (baseResponse):
