@@ -8,8 +8,6 @@ class deletePhysicalNetworkCmd (baseCmd):
         """the ID of the Physical network"""
         """Required"""
         self.id = None
-        """"""
-        self.starteventid = None
         self.required = ["id",]
 
 class deletePhysicalNetworkResponse (baseResponse):
