@@ -8,8 +8,6 @@ class deleteProjectCmd (baseCmd):
         """id of the project to be deleted"""
         """Required"""
         self.id = None
-        """"""
-        self.starteventid = None
         self.required = ["id",]
 
 class deleteProjectResponse (baseResponse):
