@@ -8,8 +8,6 @@ class deleteStorageNetworkIpRangeCmd (baseCmd):
         """the uuid of the storage network ip range"""
         """Required"""
         self.id = None
-        """"""
-        self.starteventid = None
         self.required = ["id",]
 
 class deleteStorageNetworkIpRangeResponse (baseResponse):
