@@ -8,8 +8,6 @@ class deleteVPCOfferingCmd (baseCmd):
         """the ID of the VPC offering"""
         """Required"""
         self.id = None
-        """"""
-        self.starteventid = None
         self.required = ["id",]
 
 class deleteVPCOfferingResponse (baseResponse):
