@@ -14,8 +14,6 @@ class disableAccountCmd (baseCmd):
         self.domainid = None
         """Account id"""
         self.id = None
-        """"""
-        self.starteventid = None
         self.required = ["lock",]
 
 class disableAccountResponse (baseResponse):
