@@ -8,8 +8,6 @@ class disableStaticNatCmd (baseCmd):
         """the public IP address id for which static nat feature is being disableed"""
         """Required"""
         self.ipaddressid = None
-        """"""
-        self.starteventid = None
         self.required = ["ipaddressid",]
 
 class disableStaticNatResponse (baseResponse):
