@@ -8,8 +8,6 @@ class disassociateIpAddressCmd (baseCmd):
         """the id of the public ip address to disassociate"""
         """Required"""
         self.id = None
-        """"""
-        self.starteventid = None
         self.required = ["id",]
 
 class disassociateIpAddressResponse (baseResponse):
