@@ -5,7 +5,7 @@ from baseResponse import *
 class listUsersCmd (baseCmd):
     def __init__(self):
         self.isAsync = "false"
-        """List resources by account. Must be used with the domainId parameter."""
+        """list resources by account. Must be used with the domainId parameter."""
         self.account = None
         """List users by account type. Valid types include admin, domain-admin, read-only-admin, or user."""
         self.accounttype = None
