@@ -11,8 +11,6 @@ class migrateSystemVmCmd (baseCmd):
         """the ID of the virtual machine"""
         """Required"""
         self.virtualmachineid = None
-        """"""
-        self.starteventid = None
         self.required = ["hostid","virtualmachineid",]
 
 class migrateSystemVmResponse (baseResponse):
