@@ -14,8 +14,6 @@ class removeVpnUserCmd (baseCmd):
         self.domainid = None
         """remove vpn user from the project"""
         self.projectid = None
-        """"""
-        self.starteventid = None
         self.required = ["username",]
 
 class removeVpnUserResponse (baseResponse):
